(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     76714,       1793]
NotebookOptionsPosition[     74935,       1733]
NotebookOutlinePosition[     75393,       1751]
CellTagsIndexPosition[     75350,       1748]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Vertices", "Subsection",
 CellChangeTimes->{{3.651605038242518*^9, 3.6516050393398466`*^9}}],

Cell["Position of the tetrahedron vertices:", "Text",
 CellChangeTimes->{{3.6521068360698304`*^9, 3.6521068570511436`*^9}, 
   3.6521069112986174`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        SqrtBox[
         FractionBox["2", "3"]], "-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["6"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["3"]}]]}], ",", 
       RowBox[{"-", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["6"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["3"]}]]}], ",", 
       FractionBox["1", "2"], ",", 
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["6"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["3"]], ",", "0", ",", 
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          SqrtBox["6"]}]]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.651603483979564*^9, 3.651603493487595*^9}}],

Cell["They are labeled as follows:", "Text",
 CellChangeTimes->{{3.652106867101137*^9, 3.652106875727596*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Vind", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6516038183058825`*^9, 3.651603892824192*^9}}],

Cell["Directions in which they will be moved in unwrapping:", "Text",
 CellChangeTimes->{{3.652106891300357*^9, 3.652106906079826*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Vdir", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Normalize", "[", 
      RowBox[{"V", "\[LeftDoubleBracket]", 
       RowBox[{"Vind", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}],
        "\[RightDoubleBracket]"}], "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "Vind", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6516038962521706`*^9, 3.651603954825405*^9}, 
   3.6516050432360764`*^9, {3.6516061742610164`*^9, 3.651606201750198*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Edges", "Subsection",
 CellChangeTimes->{{3.651605047575854*^9, 3.6516050482023487`*^9}, {
  3.651690745900257*^9, 3.6516907469015822`*^9}}],

Cell["Edges are composed of vertices in the following way:", "Text",
 CellChangeTimes->{{3.652106918310241*^9, 3.652106929383948*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Eind", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.651604232593191*^9, 3.6516042586235247`*^9}}],

Cell["Following stores end-points of the edges:", "Text",
 CellChangeTimes->{{3.6521069464089136`*^9, 3.6521069648264933`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"edges", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"V", "\[LeftDoubleBracket]", 
        RowBox[{"Eind", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{"V", "\[LeftDoubleBracket]", 
        RowBox[{"Eind", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "6"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6516045476339283`*^9, 3.6516045524611163`*^9}, {
   3.65160459731336*^9, 3.651604654523317*^9}, 3.6516049287280912`*^9, 
   3.6516051377385745`*^9}],

Cell["Directions in which the edges will be moved in unwrapping:", "Text",
 CellChangeTimes->{{3.652106970296633*^9, 3.6521069827072415`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Edir", "=", 
   RowBox[{
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Normalize", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"Eind", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"Eind", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "2"], "]"}], ",", 
        RowBox[{"Normalize", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"Eind", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"Eind", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "2"], "]"}]}], "}"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "6"}], "}"}]}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{
        RowBox[{
        "Vdir", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ".", 
        RowBox[{
        "Vdir", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
       "]"}], "/", "2"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EVdir", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Vdir", "\[LeftDoubleBracket]", 
        RowBox[{"Eind", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Vdir", "\[LeftDoubleBracket]", 
        RowBox[{"Eind", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}]}], "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "6"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.651604265624853*^9, 3.651604327072037*^9}, {
  3.6516045879042196`*^9, 3.6516045923135586`*^9}, {3.651604918527092*^9, 
  3.6516049258620105`*^9}, {3.651605141811306*^9, 3.651605144417463*^9}, {
  3.651606205878521*^9, 3.6516062061910243`*^9}, {3.6516062764481163`*^9, 
  3.651606291362052*^9}, {3.6516069058207426`*^9, 3.6516069257251196`*^9}, {
  3.6516855071973853`*^9, 3.651685508254478*^9}, {3.6660783442359037`*^9, 
  3.666078416415024*^9}, {3.6660784732507973`*^9, 3.666078474274396*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Faces", "Subsection",
 CellChangeTimes->{{3.6516050541700196`*^9, 3.6516050595791993`*^9}, {
  3.6516854179322677`*^9, 3.6516854187889423`*^9}}],

Cell["Faces are composed of vertices in the following way:", "Text",
 CellChangeTimes->{{3.652106999909403*^9, 3.6521070040928645`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"find", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6516050835798407`*^9, 3.6516050909670353`*^9}}],

Cell["Following stores vertices defining the edges:", "Text",
 CellChangeTimes->{{3.6521070172743855`*^9, 3.6521070313334846`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"faces", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"V", "\[LeftDoubleBracket]", 
        RowBox[{"find", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{"V", "\[LeftDoubleBracket]", 
        RowBox[{"find", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{"V", "\[LeftDoubleBracket]", 
        RowBox[{"find", "\[LeftDoubleBracket]", 
         RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
        "\[RightDoubleBracket]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.651605093647107*^9, 3.6516051328809795`*^9}}],

Cell["Directions in which the faces will be moved in unwrapping:", "Text",
 CellChangeTimes->{{3.652107038505397*^9, 3.652107043207099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fdir", "=", 
   RowBox[{
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Normalize", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "3"], "]"}], ",", 
        RowBox[{"Normalize", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "3"], "]"}], ",", 
        RowBox[{"Normalize", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{"V", "\[LeftDoubleBracket]", 
            RowBox[{"find", "\[LeftDoubleBracket]", 
             RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "3"], "]"}]}], "}"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], "/", "3"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.651604265624853*^9, 3.651604327072037*^9}, {
  3.6516045879042196`*^9, 3.6516045923135586`*^9}, {3.651604918527092*^9, 
  3.6516049258620105`*^9}, {3.651605141811306*^9, 3.6516051949152575`*^9}, {
  3.651605272040056*^9, 3.651605273005727*^9}, {3.6516069433592815`*^9, 
  3.6516069438508525`*^9}, {3.6516905806288023`*^9, 3.6516906156570263`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.6517435766998143`*^9, 3.6517435841502686`*^9}, {
   3.652106662252323*^9, 3.6521066646898546`*^9}, 3.6521070510108223`*^9}],

Cell[TextData[{
 "Cases for the ",
 StyleBox["q",
  FontSlant->"Italic"],
 "-compatibility:\n   - first index determines the case within the edge \
compatibility:\n        * 1 case of all edges compatible (zero 2-compatible \
edges)\n        * 1 case of single 2-compatible edge (five compatible edges)\n\
        * 2 cases of two 2-compatible edges (four compatible edges)\n        \
* 3 cases of three 2-compatible edges (three compatible edges)\n        * 2 \
cases of four 2-compatible edges (two compatible edges)\n        * 1 case of \
five 2-compatible edges (one compatible edge)\n        * 1 case of all edges \
being 2-compatible (no compatible edges)\n   - second index determines the \
case within (faces and bulk compatibility)\n   - third index differentiates \
between indexing the six edges (1), four faces (2) and the bulk (3)\n   - \
fourth index is the ",
 StyleBox["q",
  FontSlant->"Italic"],
 " that determines the compatibility of the chosen element\n\nFor example \
element (6,3,2,2) determines the third case with three 2-compatible and three \
compatible edges (in specific configuration) addressing face (2) number 2, \
i.e. {3,2,1}, which is 3-compatible\n\nFor reference:\n   Edges:\n      1: \
{1,2}\n      2: {1,3}\n      3: {1,4}\n      4: {2,3}\n      5: {2,4}\n      \
6: {3,4}\n      \n   Faces:\n      1: {2,3,4}\n      2: {3,2,1}\n      3: \
{4,1,2}\n      4: {1,4,3}\n      \n   Bulk:\n      1: {1,2,3,4}"
}], "Text",
 CellChangeTimes->{{3.6521070694246244`*^9, 3.6521076461293244`*^9}, {
  3.652107796446451*^9, 3.652107901654597*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", "6", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "5", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "5", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "5", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "5", ",", "5", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "7", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "4"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "4", ",", "5"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "5", ",", "5"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "5", ",", "5", ",", "5"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "5", ",", "5", ",", "5"}], "}"}], ",", 
         RowBox[{"{", "8", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "5", ",", "5", ",", "5"}], "}"}], ",", 
         RowBox[{"{", "9", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6521066683617516`*^9, 3.652106778005051*^9}, {
   3.654869970479957*^9, 3.65486999870533*^9}, {3.654870098753254*^9, 
   3.6548701014228945`*^9}, {3.6548702283686285`*^9, 
   3.6548702309351444`*^9}, {3.6548703079686117`*^9, 3.654870323280383*^9}, {
   3.65487048828592*^9, 3.65487050062976*^9}, {3.6548706152112303`*^9, 
   3.654870648993429*^9}, {3.6548708160970974`*^9, 3.6548708676007805`*^9}, 
   3.66470345185264*^9, {3.664703627208227*^9, 3.664703665738139*^9}, {
   3.6647037298998327`*^9, 3.664703850881513*^9}, {3.664703914761183*^9, 
   3.664703954022319*^9}, {3.664704401000231*^9, 3.664704662171022*^9}}],

Cell["Number of all cases", "Text",
 CellChangeTimes->{{3.6521077385276995`*^9, 3.652107741641981*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plus", "@@", 
  RowBox[{"Length", "/@", "data"}]}]], "Input",
 CellChangeTimes->{{3.6521077158207946`*^9, 3.652107735400219*^9}}],

Cell[BoxData["34"], "Output",
 CellChangeTimes->{{3.652107721661894*^9, 3.652107735712695*^9}, 
   3.652107933856533*^9, {3.652107999579506*^9, 3.6521080432549033`*^9}, 
   3.652110223081665*^9, 3.6542426939679155`*^9, 3.6548695979979553`*^9, 
   3.6548712726737757`*^9, 3.661488856457492*^9, 3.664695480634285*^9, 
   3.664804496317459*^9, 3.66480726802638*^9, 3.664809826355659*^9, 
   3.666077516575842*^9, {3.666078483603516*^9, 3.666078509339857*^9}, 
   3.666091373464539*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object", "Subsection",
 CellChangeTimes->{{3.651605204917205*^9, 3.651605206187321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"q", ">", 
       RowBox[{"Length", "[", 
        RowBox[{
        "data", "\[LeftDoubleBracket]", "t", "\[RightDoubleBracket]"}], 
        "]"}]}], ",", 
      RowBox[{"q", "=", 
       RowBox[{"Length", "[", 
        RowBox[{
        "data", "\[LeftDoubleBracket]", "t", "\[RightDoubleBracket]"}], 
        "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"comp", "=", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", "1", "]"}], ",", "col1"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", "b", "]"}], ",", "col2"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"0.65", "-", 
           RowBox[{"d", "/", "4"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "d"}], "+", "1"}], "4"], "]"}], "]"}], ",", 
         "col1"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"0.65", "-", 
           RowBox[{"d", "/", "4"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "d"}], "+", "1"}], "4"], "]"}], "]"}], ",", 
         "col2"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"b", 
           RowBox[{"(", 
            RowBox[{"0.65", "-", 
             RowBox[{"d", "/", "4"}]}], ")"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           RowBox[{"b", 
            FractionBox[
             RowBox[{
              RowBox[{"2", "d"}], "+", "1"}], "4"]}], "]"}], "]"}], ",", 
         "col3"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"0.65", "-", 
           RowBox[{"d", "/", "4"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "d"}], "+", "1"}], "6"], "]"}], "]"}], ",", 
         "col1"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"0.65", "-", 
           RowBox[{"d", "/", "4"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "d"}], "+", "1"}], "4"], "]"}], "]"}], ",", 
         "col2"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"0.65", "-", 
           RowBox[{"d", "/", "4"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"2", "d"}], "+", "1"}], "4"], "]"}], "]"}], ",", 
         "col3"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"Opacity", "[", 
          RowBox[{"b", 
           RowBox[{"(", 
            RowBox[{"0.65", "-", 
             RowBox[{"d", "/", "4"}]}], ")"}]}], "]"}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Opacity", "[", 
           RowBox[{"b", 
            FractionBox[
             RowBox[{
              RowBox[{"2", "d"}], "+", "1"}], "4"]}], "]"}], "]"}], ",", 
         "col4"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", 
            RowBox[{"Opacity", "[", "o", "]"}]}], "]"}], ",", 
          RowBox[{"Sphere", "[", 
           RowBox[{
            RowBox[{"V", "+", 
             RowBox[{"d", " ", "Vdir"}]}], ",", "0.07"}], "]"}]}], "}"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thin", ",", 
            RowBox[{"Opacity", "[", "o", "]"}]}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"edges", "+", 
            RowBox[{"d", " ", "EVdir"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"col1", ",", 
            RowBox[{"Opacity", "[", "b", "]"}]}], "]"}], ",", 
          RowBox[{"Sphere", "[", 
           RowBox[{
            RowBox[{"V", "+", 
             RowBox[{"d", " ", "Vdir"}]}], ",", "0.08"}], "]"}]}], "}"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "3", ",", "1"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"PolyhedronData", "[", 
           RowBox[{"\"\<Tetrahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "1"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "2"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "3"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "4"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "5"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "5", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "1", ",", "6"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Tube", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "edges", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{"d", " ", 
              RowBox[{
              "Edir", "\[LeftDoubleBracket]", "6", 
               "\[RightDoubleBracket]"}]}]}], ",", "0.02"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "2", ",", "1"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{
            RowBox[{
            "faces", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "+", 
            RowBox[{"d", " ", 
             RowBox[{
             "Fdir", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "2", ",", "2"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{
            RowBox[{
            "faces", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "+", 
            RowBox[{"d", " ", 
             RowBox[{
             "Fdir", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}]}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "2", ",", "3"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{
            RowBox[{
            "faces", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "+", 
            RowBox[{"d", " ", 
             RowBox[{
             "Fdir", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}]}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"comp", "\[LeftDoubleBracket]", 
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"t", ",", "q", ",", "2", ",", "4"}], 
            "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Polygon", "[", 
           RowBox[{
            RowBox[{
            "faces", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
            "+", 
            RowBox[{"d", " ", 
             RowBox[{
             "Fdir", "\[LeftDoubleBracket]", "4", 
              "\[RightDoubleBracket]"}]}]}], "]"}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Boxed", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.2"}], ",", 
         RowBox[{"-", "1"}], ",", "0.4"}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "/@", 
             RowBox[{"Transpose", "[", 
              RowBox[{"V", "+", " ", 
               RowBox[{"1.5", "Vdir"}]}], "]"}]}], "-", "0.1"}], ",", 
           RowBox[{
            RowBox[{"Max", "/@", 
             RowBox[{"Transpose", "[", 
              RowBox[{"V", "+", " ", 
               RowBox[{"1.5", "Vdir"}]}], "]"}]}], "+", "0.1"}]}], "}"}], "//",
          "N"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Lighting", "\[Rule]", "\"\<Neutral\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
     "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Cases\>\"", ",", "12", ",", "Bold"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "1", ",", "\"\<No. of index-2 edges\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "\"\<0\>\""}], ",", 
       RowBox[{"2", "\[Rule]", "\"\<1\>\""}], ",", 
       RowBox[{"3", "\[Rule]", "\"\<2\>\""}], ",", 
       RowBox[{"4", "\[Rule]", "\"\<3\>\""}], ",", 
       RowBox[{"5", "\[Rule]", "\"\<4\>\""}], ",", 
       RowBox[{"6", "\[Rule]", "\"\<5\>\""}], ",", 
       RowBox[{"7", "\[Rule]", "\"\<6\>\""}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "Setter"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "1", ",", 
       RowBox[{"Dynamic", "[", 
        RowBox[{"\"\<Cases within (\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"Length", "[", 
           RowBox[{
           "data", "\[LeftDoubleBracket]", "t", "\[RightDoubleBracket]"}], 
           "]"}], "]"}], "<>", "\"\<)\>\""}], "]"}]}], "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"Length", "[", 
       RowBox[{"data", "\[LeftDoubleBracket]", "t", "\[RightDoubleBracket]"}],
        "]"}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "Setter"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Display options\>\"", ",", "12", ",", "Bold"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "0", ",", "\"\<Show trivial indexes\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "0.75", ",", "\"\<Distance\>\""}], "}"}], ",", "0.01",
      ",", "1.5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"o", ",", "0.1", ",", "\"\<Hypergraph opacity\>\""}], "}"}], 
     ",", "0", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ColorSlider", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "col1", "]"}], ",", 
         RowBox[{"AppearanceElements", "\[Rule]", 
          RowBox[{"{", "\"\<Swatch\>\"", "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"30", ",", "20"}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<Index-1 color\>\"", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ColorSlider", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "col2", "]"}], ",", 
         RowBox[{"AppearanceElements", "\[Rule]", 
          RowBox[{"{", "\"\<Swatch\>\"", "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"30", ",", "20"}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<Index-2 color\>\"", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ColorSlider", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "col3", "]"}], ",", 
         RowBox[{"AppearanceElements", "\[Rule]", 
          RowBox[{"{", "\"\<Swatch\>\"", "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"30", ",", "20"}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<Index-3 color\>\"", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ColorSlider", "[", 
        RowBox[{
         RowBox[{"Dynamic", "[", "col4", "]"}], ",", 
         RowBox[{"AppearanceElements", "\[Rule]", 
          RowBox[{"{", "\"\<Swatch\>\"", "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"30", ",", "20"}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<Index-4 color\>\""}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Spacer", "[", "10", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "=", "4"}], ",", 
      RowBox[{"q", "=", "4"}], ",", 
      RowBox[{"col1", "=", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.08", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{"col2", "=", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.6", ",", "0.8", ",", "0.9"}], "]"}]}], ",", 
      RowBox[{"col3", "=", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.3", ",", "0.6", ",", "0.7"}], "]"}]}], ",", 
      RowBox[{"col4", "=", 
       RowBox[{"Hue", "[", 
        RowBox[{"0", ",", "1", ",", "0.5"}], "]"}]}]}], "}"}]}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.651607398390219*^9, 3.651607423241393*^9}, {
   3.6516074630971527`*^9, 3.651607486648821*^9}, {3.651608228748695*^9, 
   3.6516082301549625`*^9}, {3.6516083016473727`*^9, 3.651608304175807*^9}, {
   3.6516083856347575`*^9, 3.6516083904826365`*^9}, {3.6516909701834226`*^9, 
   3.6516910417641244`*^9}, {3.651691258918317*^9, 3.651691286202573*^9}, {
   3.651692359117877*^9, 3.6516923638778872`*^9}, {3.6516927153667583`*^9, 
   3.6516927164489756`*^9}, {3.651743762918021*^9, 3.65174377109348*^9}, {
   3.651744095957654*^9, 3.651744154166516*^9}, {3.6517443701168976`*^9, 
   3.6517446626024055`*^9}, {3.651744750717805*^9, 3.651744831727919*^9}, {
   3.651744965696499*^9, 3.6517449711809225`*^9}, {3.651745068029397*^9, 
   3.651745128454219*^9}, {3.6517452547308717`*^9, 3.651745329260442*^9}, {
   3.6517460212588415`*^9, 3.651746031446478*^9}, {3.651746077090371*^9, 
   3.651746110464179*^9}, {3.6517462271799974`*^9, 3.651746245772944*^9}, {
   3.651746675662478*^9, 3.651746731136644*^9}, {3.6517467826331687`*^9, 
   3.6517467903053274`*^9}, {3.651746824237095*^9, 3.6517469281538963`*^9}, {
   3.651747004864051*^9, 3.65174703762127*^9}, {3.6520880455697937`*^9, 
   3.652088054761032*^9}, {3.6521037910923*^9, 3.65210379304543*^9}, {
   3.6521038442554827`*^9, 3.652103871908738*^9}, {3.652103991571636*^9, 
   3.652104194834898*^9}, {3.6521042518563204`*^9, 3.6521042550907335`*^9}, {
   3.6521043595676312`*^9, 3.652104392291609*^9}, 3.652104518901476*^9, {
   3.6521055021742506`*^9, 3.652105502846134*^9}, {3.6521055423742476`*^9, 
   3.6521055623450775`*^9}, {3.6521057460186043`*^9, 3.652105746971574*^9}, {
   3.6521059676354227`*^9, 3.652105991244794*^9}, {3.6521060990532007`*^9, 
   3.6521061344796543`*^9}, {3.6521061878268833`*^9, 
   3.6521061883581114`*^9}, {3.652106261662777*^9, 3.652106268866*^9}, {
   3.652106354197158*^9, 3.652106441390604*^9}, {3.652106479930329*^9, 
   3.6521065227381783`*^9}, {3.6521066131803308`*^9, 
   3.6521066311500883`*^9}, {3.6521080190778894`*^9, 
   3.6521080215930777`*^9}, {3.652108080519539*^9, 3.6521081392255583`*^9}, {
   3.6521082168290367`*^9, 3.652108232457469*^9}, {3.6521084866560373`*^9, 
   3.652108529134423*^9}, {3.6521085629805555`*^9, 3.6521086673044586`*^9}, {
   3.652108702363078*^9, 3.652108703956846*^9}, {3.6521087557746744`*^9, 
   3.652108756493422*^9}, {3.6521088102371473`*^9, 3.6521088372345595`*^9}, {
   3.6521091992857323`*^9, 3.652109220574247*^9}, {3.652109392365281*^9, 
   3.652109393271542*^9}, {3.6521094483516784`*^9, 3.6521095436695895`*^9}, {
   3.652109582818983*^9, 3.6521095967761383`*^9}, {3.6521096517239447`*^9, 
   3.6521097966073217`*^9}, {3.6542427221179285`*^9, 
   3.6542427512647305`*^9}, {3.654870128141038*^9, 3.654870150577774*^9}, {
   3.6548702395946155`*^9, 3.6548702454191484`*^9}, {3.6548706598279533`*^9, 
   3.6548706913052063`*^9}, {3.6548707349487467`*^9, 3.654870791819437*^9}, {
   3.6548708973213224`*^9, 3.654870900400467*^9}, {3.654870932438608*^9, 
   3.65487097686082*^9}, {3.6548710414093175`*^9, 3.654871090774867*^9}, {
   3.654871282123946*^9, 3.6548712828739357`*^9}, {3.661489088216494*^9, 
   3.661489094563583*^9}, {3.664702828690778*^9, 3.6647028670632133`*^9}, {
   3.664702947108974*^9, 3.664702983658793*^9}, {3.664703080072373*^9, 
   3.664703100422752*^9}, {3.66470313869744*^9, 3.6647031418681717`*^9}, {
   3.664703173706992*^9, 3.6647031884434977`*^9}, {3.6647032699275303`*^9, 
   3.664703374879402*^9}, {3.664703441481475*^9, 3.664703445834145*^9}, {
   3.6647035997720203`*^9, 3.664703606406682*^9}, {3.664703680793227*^9, 
   3.6647036970137568`*^9}, {3.664704046105599*^9, 3.664704066885255*^9}, {
   3.664704122268059*^9, 3.664704145410028*^9}, {3.664704294068514*^9, 
   3.664704294180099*^9}, {3.664704683638166*^9, 3.664704946497076*^9}, {
   3.664704979379315*^9, 3.664704982136767*^9}, {3.66470501728574*^9, 
   3.664705037699445*^9}, {3.664705100261615*^9, 3.664705173420197*^9}, {
   3.664705289905684*^9, 3.664705345862461*^9}, {3.664705379398735*^9, 
   3.664705387723476*^9}, {3.664705473608294*^9, 3.664705473753574*^9}, {
   3.6647055347530537`*^9, 3.66470556495763*^9}, {3.6647056640838823`*^9, 
   3.6647056864602327`*^9}, {3.664705742913352*^9, 3.664705747119772*^9}, {
   3.664706328794788*^9, 3.664706394112501*^9}, {3.664706435929614*^9, 
   3.664706436040588*^9}, {3.664706471615728*^9, 3.664706506119186*^9}, {
   3.664706823933819*^9, 3.664706842383891*^9}, {3.6647069100890493`*^9, 
   3.6647069258374434`*^9}, {3.6647069893557053`*^9, 3.664707064694128*^9}, {
   3.664707150198484*^9, 3.664707192105405*^9}, {3.6647073233941174`*^9, 
   3.664707338008725*^9}, {3.664707442810951*^9, 3.664707451584813*^9}, {
   3.664707485032691*^9, 3.664707487034768*^9}, {3.664707518188673*^9, 
   3.664707621373398*^9}, {3.664806542600809*^9, 3.66480654500694*^9}, {
   3.6648065918633947`*^9, 3.664806672706163*^9}, {3.664807047460235*^9, 
   3.664807198660589*^9}, {3.664807240882847*^9, 3.664807250647547*^9}, {
   3.664807293982251*^9, 3.66480733614607*^9}, {3.6648074124008493`*^9, 
   3.6648074688185797`*^9}, {3.666077528957364*^9, 3.6660775308932047`*^9}, {
   3.666077687976494*^9, 3.6660777180690203`*^9}, {3.666077762631935*^9, 
   3.666077769370426*^9}, {3.666077842586351*^9, 3.666077877370615*^9}, {
   3.666077937233501*^9, 3.666078037675161*^9}, {3.666078080179015*^9, 
   3.666078098447061*^9}, {3.666078140815104*^9, 3.666078152311755*^9}, {
   3.6660781912486687`*^9, 3.666078246643643*^9}, {3.666078426703443*^9, 
   3.666078431134077*^9}, {3.666078479521886*^9, 3.66607850545138*^9}, {
   3.6660913932060633`*^9, 3.6660913967690077`*^9}, {3.666091716985057*^9, 
   3.666091741676436*^9}, {3.666091796559004*^9, 3.666091823710527*^9}, {
   3.666091903743396*^9, 3.666091945786285*^9}, {3.666092049198094*^9, 
   3.666092075127673*^9}, {3.6660921406265717`*^9, 3.666092141189362*^9}, {
   3.6660921741410847`*^9, 3.666092175917513*^9}, {3.666092247672029*^9, 
   3.6660923060192833`*^9}, {3.666092361145021*^9, 3.666092412113892*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`b$$ = 1, $CellContext`d$$ = 
    0.878, $CellContext`o$$ = 0.198, $CellContext`q$$ = 7, $CellContext`t$$ = 
    7, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Style["Cases", 12, Bold]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`t$$], 1, "No. of index-2 edges"}, {
      1 -> "0", 2 -> "1", 3 -> "2", 4 -> "3", 5 -> "4", 6 -> "5", 7 -> 
       "6"}}, {{
       Hold[$CellContext`q$$], 1, 
       Dynamic[
        StringJoin["Cases within (", 
         ToString[
          Length[
           Part[$CellContext`data, $CellContext`t$$]]], ")"]]}, 
      Dynamic[
       Range[
        Length[
         Part[$CellContext`data, $CellContext`t$$]]]]}, {
      Hold[
       Style["Display options", 12, Bold]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`b$$], 0, "Show trivial indexes"}, {0, 1}}, {{
       Hold[$CellContext`d$$], 0.75, "Distance"}, 0.01, 1.5}, {{
       Hold[$CellContext`o$$], 0.1, "Hypergraph opacity"}, 0, 1}, {
      Hold[
       Row[{
         ColorSlider[
          Dynamic[$CellContext`col1], AppearanceElements -> {"Swatch"}, 
          ImageSize -> {30, 20}], "Index-1 color", 
         Spacer[20], 
         ColorSlider[
          Dynamic[$CellContext`col2], AppearanceElements -> {"Swatch"}, 
          ImageSize -> {30, 20}], "Index-2 color", 
         Spacer[20], 
         ColorSlider[
          Dynamic[$CellContext`col3], AppearanceElements -> {"Swatch"}, 
          ImageSize -> {30, 20}], "Index-3 color", 
         Spacer[20], 
         ColorSlider[
          Dynamic[$CellContext`col4], AppearanceElements -> {"Swatch"}, 
          ImageSize -> {30, 20}], "Index-4 color"}, 
        Spacer[10]]], Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    750., {335., 342.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`t$29117$$ = 
    False, $CellContext`b$29118$$ = False, $CellContext`d$29119$$ = 
    0, $CellContext`o$29120$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`b$$ = 0, $CellContext`d$$ = 
        0.75, $CellContext`o$$ = 0.1, $CellContext`q$$ = 1, $CellContext`t$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$29117$$, False], 
        Hold[$CellContext`b$$, $CellContext`b$29118$$, False], 
        Hold[$CellContext`d$$, $CellContext`d$29119$$, 0], 
        Hold[$CellContext`o$$, $CellContext`o$29120$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> (If[$CellContext`q$$ > Length[
           Part[$CellContext`data, $CellContext`t$$]], $CellContext`q$$ = 
         Length[
           Part[$CellContext`data, $CellContext`t$$]]]; $CellContext`comp = {
          Directive[
           Opacity[1], $CellContext`col1], 
          Directive[
           Opacity[$CellContext`b$$], $CellContext`col2], 
          Directive[
           Opacity[0.65 - $CellContext`d$$/4], 
           EdgeForm[
            Opacity[(2 $CellContext`d$$ + 1)/4]], $CellContext`col1], 
          Directive[
           Opacity[0.65 - $CellContext`d$$/4], 
           EdgeForm[
            Opacity[(2 $CellContext`d$$ + 1)/4]], $CellContext`col2], 
          Directive[
           Opacity[$CellContext`b$$ (0.65 - $CellContext`d$$/4)], 
           EdgeForm[
            
            Opacity[$CellContext`b$$ ((2 $CellContext`d$$ + 1)/
              4)]], $CellContext`col3], 
          Directive[
           Opacity[0.65 - $CellContext`d$$/4], 
           EdgeForm[
            Opacity[(2 $CellContext`d$$ + 1)/6]], $CellContext`col1], 
          Directive[
           Opacity[0.65 - $CellContext`d$$/4], 
           EdgeForm[
            Opacity[(2 $CellContext`d$$ + 1)/4]], $CellContext`col2], 
          Directive[
           Opacity[0.65 - $CellContext`d$$/4], 
           EdgeForm[
            Opacity[(2 $CellContext`d$$ + 1)/4]], $CellContext`col3], 
          Directive[
           Opacity[$CellContext`b$$ (0.65 - $CellContext`d$$/4)], 
           EdgeForm[
            
            Opacity[$CellContext`b$$ ((2 $CellContext`d$$ + 1)/
              4)]], $CellContext`col4]}; Graphics3D[{{
           Directive[Gray, 
            Opacity[$CellContext`o$$]], 
           
           Sphere[$CellContext`V + $CellContext`d$$ $CellContext`Vdir, 
            0.07]}, {
           Directive[Gray, Thin, 
            Opacity[$CellContext`o$$]], 
           Line[$CellContext`edges + $CellContext`d$$ $CellContext`EVdir]}, {
           Directive[$CellContext`col1, 
            Opacity[$CellContext`b$$]], 
           
           Sphere[$CellContext`V + $CellContext`d$$ $CellContext`Vdir, 
            0.08]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 3, 
             1]], 
           PolyhedronData["Tetrahedron", "Faces"]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             1]], 
           Tube[
           Part[$CellContext`edges, 1] + $CellContext`d$$ 
             Part[$CellContext`Edir, 1], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             2]], 
           Tube[
           Part[$CellContext`edges, 2] + $CellContext`d$$ 
             Part[$CellContext`Edir, 2], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             3]], 
           Tube[
           Part[$CellContext`edges, 3] + $CellContext`d$$ 
             Part[$CellContext`Edir, 3], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             4]], 
           Tube[
           Part[$CellContext`edges, 4] + $CellContext`d$$ 
             Part[$CellContext`Edir, 4], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             5]], 
           Tube[
           Part[$CellContext`edges, 5] + $CellContext`d$$ 
             Part[$CellContext`Edir, 5], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 1, 
             6]], 
           Tube[
           Part[$CellContext`edges, 6] + $CellContext`d$$ 
             Part[$CellContext`Edir, 6], 0.02]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 2, 
             1]], 
           Polygon[
           Part[$CellContext`faces, 1] + $CellContext`d$$ 
             Part[$CellContext`Fdir, 1]]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 2, 
             2]], 
           Polygon[
           Part[$CellContext`faces, 2] + $CellContext`d$$ 
             Part[$CellContext`Fdir, 2]]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 2, 
             3]], 
           Polygon[
           Part[$CellContext`faces, 3] + $CellContext`d$$ 
             Part[$CellContext`Fdir, 3]]}, {
           Part[$CellContext`comp, 
            
            Part[$CellContext`data, $CellContext`t$$, $CellContext`q$$, 2, 
             4]], 
           Polygon[
           Part[$CellContext`faces, 4] + $CellContext`d$$ 
             Part[$CellContext`Fdir, 4]]}}, Boxed -> False, 
         ViewPoint -> {-1.2, -1, 0.4}, PlotRange -> Transpose[
           N[{Map[Min, 
               Transpose[$CellContext`V + 1.5 $CellContext`Vdir]] - 0.1, 
             Map[Max, 
               Transpose[$CellContext`V + 1.5 $CellContext`Vdir]] + 0.1}]], 
         Lighting -> "Neutral", ImageSize -> 600]), "Specifications" :> {
        Style[
        "Cases", 12, Bold], {{$CellContext`t$$, 1, "No. of index-2 edges"}, {
         1 -> "0", 2 -> "1", 3 -> "2", 4 -> "3", 5 -> "4", 6 -> "5", 7 -> 
          "6"}, ControlType -> Setter}, {{$CellContext`q$$, 1, 
          Dynamic[
           StringJoin["Cases within (", 
            ToString[
             Length[
              Part[$CellContext`data, $CellContext`t$$]]], ")"]]}, 
         Dynamic[
          Range[
           Length[
            Part[$CellContext`data, $CellContext`t$$]]]], ControlType -> 
         Setter}, Delimiter, 
        Style[
        "Display options", 12, 
         Bold], {{$CellContext`b$$, 0, "Show trivial indexes"}, {0, 
         1}}, {{$CellContext`d$$, 0.75, "Distance"}, 0.01, 
         1.5}, {{$CellContext`o$$, 0.1, "Hypergraph opacity"}, 0, 1}, 
        Row[{
          ColorSlider[
           Dynamic[$CellContext`col1], AppearanceElements -> {"Swatch"}, 
           ImageSize -> {30, 20}], "Index-1 color", 
          Spacer[20], 
          ColorSlider[
           Dynamic[$CellContext`col2], AppearanceElements -> {"Swatch"}, 
           ImageSize -> {30, 20}], "Index-2 color", 
          Spacer[20], 
          ColorSlider[
           Dynamic[$CellContext`col3], AppearanceElements -> {"Swatch"}, 
           ImageSize -> {30, 20}], "Index-3 color", 
          Spacer[20], 
          ColorSlider[
           Dynamic[$CellContext`col4], AppearanceElements -> {"Swatch"}, 
           ImageSize -> {30, 20}], "Index-4 color"}, 
         Spacer[10]]}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{805., {492., 499.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({{$CellContext`q$$ = 
         4, $CellContext`data = {{{{1, 1, 1, 1, 1, 1}, {3, 3, 3, 3}, {6}}, {{
             1, 1, 1, 1, 1, 1}, {3, 3, 3, 3}, {7}}, {{1, 1, 1, 1, 1, 1}, {3, 
             3, 3, 4}, {7}}, {{1, 1, 1, 1, 1, 1}, {3, 3, 4, 4}, {7}}, {{1, 1, 
             1, 1, 1, 1}, {3, 4, 4, 4}, {7}}, {{1, 1, 1, 1, 1, 1}, {4, 4, 4, 
             4}, {7}}}, {{{1, 1, 1, 1, 1, 2}, {4, 3, 3, 4}, {7}}, {{1, 1, 1, 
             1, 1, 2}, {4, 3, 4, 4}, {7}}, {{1, 1, 1, 1, 1, 2}, {4, 4, 4, 
             4}, {7}}}, {{{1, 1, 1, 1, 2, 2}, {4, 3, 4, 4}, {7}}, {{1, 1, 1, 
             1, 2, 2}, {4, 4, 4, 4}, {7}}, {{2, 1, 1, 1, 1, 2}, {4, 4, 4, 
             4}, {7}}}, {{{2, 1, 1, 2, 1, 2}, {4, 4, 4, 4}, {7}}, {{2, 2, 1, 
             2, 1, 1}, {4, 4, 4, 4}, {7}}, {{2, 2, 1, 2, 1, 1}, {4, 4, 4, 
             4}, {8}}, {{2, 2, 1, 2, 1, 1}, {4, 5, 4, 4}, {8}}, {{1, 1, 2, 1, 
             2, 2}, {4, 3, 4, 4}, {7}}, {{1, 1, 2, 1, 2, 2}, {4, 4, 4, 4}, {
             7}}, {{1, 1, 2, 1, 2, 2}, {4, 4, 4, 4}, {8}}}, {{{2, 2, 2, 2, 1, 
             1}, {4, 4, 4, 4}, {7}}, {{2, 2, 2, 2, 1, 1}, {4, 4, 4, 4}, {
             8}}, {{2, 2, 2, 2, 1, 1}, {4, 5, 4, 4}, {8}}, {{1, 2, 2, 2, 2, 
             1}, {4, 4, 4, 4}, {7}}}, {{{2, 2, 2, 2, 2, 1}, {4, 4, 4, 4}, {
             7}}, {{2, 2, 2, 2, 2, 1}, {4, 4, 4, 4}, {8}}, {{2, 2, 2, 2, 2, 
             1}, {4, 5, 4, 4}, {8}}, {{2, 2, 2, 2, 2, 1}, {4, 5, 5, 4}, {
             8}}}, {{{2, 2, 2, 2, 2, 2}, {4, 4, 4, 4}, {7}}, {{2, 2, 2, 2, 2, 
             2}, {4, 4, 4, 4}, {8}}, {{2, 2, 2, 2, 2, 2}, {4, 4, 4, 5}, {
             8}}, {{2, 2, 2, 2, 2, 2}, {4, 4, 5, 5}, {8}}, {{2, 2, 2, 2, 2, 
             2}, {4, 5, 5, 5}, {8}}, {{2, 2, 2, 2, 2, 2}, {5, 5, 5, 5}, {
             8}}, {{2, 2, 2, 2, 2, 2}, {5, 5, 5, 5}, {9}}}}, $CellContext`t$$ = 
         4, $CellContext`comp = {
           Directive[
            Opacity[1], 
            Hue[0.08, 1, 1]], 
           Directive[
            Opacity[0], 
            Hue[0.6, 0.8, 0.9]], 
           Directive[
            Opacity[0.4625], 
            EdgeForm[
             Opacity[0.625]], 
            Hue[0.08, 1, 1]], 
           Directive[
            Opacity[0.4625], 
            EdgeForm[
             Opacity[0.625]], 
            Hue[0.6, 0.8, 0.9]], 
           Directive[
            Opacity[0.], 
            EdgeForm[
             Opacity[0.]], 
            Hue[0.3, 0.6, 0.7]], 
           Directive[
            Opacity[0.4625], 
            EdgeForm[
             Opacity[0.41666666666666663`]], 
            Hue[0.08, 1, 1]], 
           Directive[
            Opacity[0.4625], 
            EdgeForm[
             Opacity[0.625]], 
            Hue[0.6, 0.8, 0.9]], 
           Directive[
            Opacity[0.4625], 
            EdgeForm[
             Opacity[0.625]], 
            Hue[0.3, 0.6, 0.7]], 
           Directive[
            Opacity[0.], 
            EdgeForm[
             Opacity[0.]], 
            Hue[0, 1, 0.5]]}, $CellContext`col1 = 
         Hue[0.08, 1, 1], $CellContext`col2 = 
         Hue[0.6, 0.8, 0.9], $CellContext`col3 = 
         Hue[0.3, 0.6, 0.7], $CellContext`col4 = 
         Hue[0, 1, 0.5], $CellContext`V = {{
           0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), (-1)/2, (-1)/(
            2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), 1/2, (-1)/(2 Sqrt[6])}, {
           1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}}, $CellContext`Vdir = {{0, 0, 
           1}, {-Sqrt[2]/3, -Sqrt[2/3], (-1)/3}, {-Sqrt[2]/3, 
            Sqrt[2/3], (-1)/3}, {(2 Sqrt[2])/3, 0, (-1)/
            3}}, $CellContext`edges = {{{
            0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), (-1)/
             2, (-1)/(2 Sqrt[6])}}, {{
            0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), 1/2, (-1)/(2 
             Sqrt[6])}}, {{0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}}, {{(-1)/(2 Sqrt[3]), (-1)/
             2, (-1)/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), 1/2, (-1)/(2 
             Sqrt[6])}}, {{(-1)/(2 Sqrt[3]), (-1)/2, (-1)/(2 Sqrt[6])}, {
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}}, {{(-1)/(2 Sqrt[3]), 1/2, (-1)/(
             2 Sqrt[6])}, {
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}}}, $CellContext`EVdir = {{{0, 0, 
            1}, {-Sqrt[2]/3, -Sqrt[2/3], (-1)/3}}, {{0, 0, 1}, {-Sqrt[2]/3, 
             Sqrt[2/3], (-1)/3}}, {{0, 0, 
            1}, {(2 Sqrt[2])/3, 0, (-1)/3}}, {{-Sqrt[2]/3, -Sqrt[2/3], (-1)/
             3}, {-Sqrt[2]/3, 
             Sqrt[2/3], (-1)/3}}, {{-Sqrt[2]/3, -Sqrt[2/3], (-1)/
             3}, {(2 Sqrt[2])/3, 0, (-1)/3}}, {{-Sqrt[2]/3, 
             Sqrt[2/3], (-1)/3}, {(2 Sqrt[2])/3, 0, (-1)/
             3}}}, $CellContext`Edir = {{{-Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), -
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4]), ((Sqrt[2/3] - 1/Sqrt[
               6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}, {-
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), -
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4]), ((Sqrt[2/3] - 1/Sqrt[
               6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}}, {{-
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), 
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4]), ((Sqrt[2/3] - 1/Sqrt[
               6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}, {-
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), 
             Cos[ArcCos[(-1)/3]/2]/(4 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4]), ((Sqrt[2/3] - 1/Sqrt[
               6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}}, {{
            Cos[ArcCos[(-1)/3]/2]/(2 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), 
             0, ((Sqrt[2/3] - 1/Sqrt[6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}, {
            Cos[ArcCos[(-1)/3]/2]/(2 
             Sqrt[3 (1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4)]), 
             0, ((Sqrt[2/3] - 1/Sqrt[6]) Cos[ArcCos[(-1)/3]/2])/(2 
             Sqrt[1/12 + (Sqrt[2/3] - 1/Sqrt[6])^2/4])}}, {{-(Sqrt[2/3] 
              Cos[ArcCos[(-1)/3]/2]), 
             0, -(Cos[ArcCos[(-1)/3]/2]/Sqrt[3])}, {-(Sqrt[2/3] 
              Cos[ArcCos[(-1)/3]/2]), 
             0, -(Cos[ArcCos[(-1)/3]/2]/Sqrt[3])}}, {{
            Cos[ArcCos[(-1)/3]/2]/Sqrt[
             6], -(Cos[ArcCos[(-1)/3]/2]/Sqrt[2]), -(Cos[ArcCos[(-1)/3]/2]/
              Sqrt[3])}, {
            Cos[ArcCos[(-1)/3]/2]/Sqrt[
             6], -(Cos[ArcCos[(-1)/3]/2]/Sqrt[2]), -(Cos[ArcCos[(-1)/3]/2]/
              Sqrt[3])}}, {{
            Cos[ArcCos[(-1)/3]/2]/Sqrt[6], Cos[ArcCos[(-1)/3]/2]/Sqrt[
             2], -(Cos[ArcCos[(-1)/3]/2]/Sqrt[3])}, {
            Cos[ArcCos[(-1)/3]/2]/Sqrt[6], Cos[ArcCos[(-1)/3]/2]/Sqrt[
             2], -(Cos[ArcCos[(-1)/3]/2]/Sqrt[
              3])}}}, $CellContext`faces = {{{(-1)/(2 Sqrt[3]), (-1)/2, (-1)/(
             2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), 1/2, (-1)/(2 Sqrt[6])}, {
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}}, {{(-1)/(2 Sqrt[3]), 1/2, (-1)/(
             2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), (-1)/2, (-1)/(2 Sqrt[6])}, {
            0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}}, {{
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}, {
            0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), (-1)/
             2, (-1)/(2 Sqrt[6])}}, {{0, 0, Sqrt[2/3] - 1/(2 Sqrt[6])}, {
            1/Sqrt[3], 0, (-1)/(2 Sqrt[6])}, {(-1)/(2 Sqrt[3]), 1/2, (-1)/(2 
             Sqrt[6])}}}, $CellContext`Fdir = {{{0, 0, (-1)/3}, {
            0, 0, (-1)/3}, {
            0, 0, (-1)/3}}, {{(-1)/(9 
             Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 
             0, (Sqrt[2/3] - Sqrt[3/2]/2)/(9 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {(-1)/(9 
             Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 
             0, (Sqrt[2/3] - Sqrt[3/2]/2)/(9 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {(-1)/(9 
             Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 
             0, (Sqrt[2/3] - Sqrt[3/2]/2)/(9 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}}, {{
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), (-1)/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), (-1)/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), (-1)/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}}, {{
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 1/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 1/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9])}, {
            1/(18 Sqrt[3 (1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9)]), 1/(18 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/9]), (Sqrt[2/3] - 
              Sqrt[3/2]/2)/(9 
             Sqrt[1/27 + (Sqrt[2/3] - Sqrt[3/2]/2)^2/
                9])}}}}; {$CellContext`t$$ = 4, $CellContext`q$$ = 
         4, $CellContext`col1 = Hue[0.08, 1, 1], $CellContext`col2 = 
         Hue[0.6, 0.8, 0.9], $CellContext`col3 = 
         Hue[0.3, 0.6, 0.7], $CellContext`col4 = Hue[0, 1, 0.5]}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.664806617094183*^9, 3.664806641792809*^9}, 
   3.66480667385043*^9, 3.6648070510453997`*^9, {3.6648070882530003`*^9, 
   3.664807129501655*^9}, {3.664807176307213*^9, 3.664807199189986*^9}, {
   3.664807244988449*^9, 3.664807336861733*^9}, {3.6648074559348173`*^9, 
   3.6648074695541687`*^9}, 3.6648098264813223`*^9, {3.666077516672014*^9, 
   3.6660775323055964`*^9}, {3.666077701338937*^9, 3.666077718764928*^9}, 
   3.6660777709802856`*^9, {3.666077862990843*^9, 3.666077877912345*^9}, {
   3.6660779395838223`*^9, 3.666078038305952*^9}, 3.666078153388196*^9, {
   3.666078224339102*^9, 3.666078247588626*^9}, 3.666078432318688*^9, {
   3.666078480969995*^9, 3.6660785094122477`*^9}, {3.666091373568493*^9, 
   3.666091399402657*^9}, 3.6660917475902643`*^9, {3.666091803664263*^9, 
   3.666091824546029*^9}, {3.666091911695302*^9, 3.666091947242721*^9}, {
   3.666092070536127*^9, 3.666092075581793*^9}, 3.6660921421059027`*^9, 
   3.666092177430497*^9, {3.666092248736966*^9, 3.666092306427247*^9}, {
   3.666092362686537*^9, 3.666092412728553*^9}}]
}, Open  ]],

Cell["\<\
Case study for compatibility index for four observables (tetrahedron corners) \
and their subsets:
- edges colors depict compatibility index between pairs of observables
- faces colors depict compatibility index of triplets of observables
- bulk represents compatibility index for the whole quadruplet of observables

Distance slider unwraps the tetrahedron elements for clarity. Possibilities \
are first grouped by the number of index-2 edges, i.e. pairs of incompatible \
measurements within the set. Each group then contains cases within. Trivial \
elements (index-1 vertices, index-2 edges, index-3 faces or index-4 bulk) are \
not displayed, however can be shown.\
\>", "Text",
 CellChangeTimes->{{3.664807497863451*^9, 3.664807510575379*^9}, {
  3.6648075495690937`*^9, 3.664807574217184*^9}, {3.664807635756023*^9, 
  3.664807742720614*^9}, {3.664808133021083*^9, 3.664808149287835*^9}, {
  3.6648081916103687`*^9, 3.664808334430593*^9}, {3.666092333257442*^9, 
  3.6660923381612797`*^9}}]
}, Open  ]]
},
WindowSize->{1097, 1049},
WindowMargins->{{147, Automatic}, {Automatic, 74}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 98, 1, 54, "Subsection"],
Cell[680, 25, 151, 2, 37, "Text"],
Cell[834, 29, 1225, 44, 73, "Input"],
Cell[2062, 75, 110, 1, 37, "Text"],
Cell[2175, 78, 207, 5, 35, "Input"],
Cell[2385, 85, 135, 1, 37, "Text"],
Cell[2523, 88, 618, 14, 78, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3178, 107, 146, 2, 54, "Subsection"],
Cell[3327, 111, 134, 1, 37, "Text"],
Cell[3464, 114, 545, 17, 35, "Input"],
Cell[4012, 133, 127, 1, 37, "Text"],
Cell[4142, 136, 790, 19, 36, "Input"],
Cell[4935, 157, 142, 1, 37, "Text"],
Cell[5080, 160, 2829, 64, 194, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7946, 229, 150, 2, 54, "Subsection"],
Cell[8099, 233, 136, 1, 37, "Text"],
Cell[8238, 236, 461, 13, 35, "Input"],
Cell[8702, 251, 131, 1, 37, "Text"],
Cell[8836, 254, 884, 21, 36, "Input"],
Cell[9723, 277, 140, 1, 37, "Text"],
Cell[9866, 280, 2870, 61, 234, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12773, 346, 172, 2, 54, "Subsection"],
Cell[12948, 350, 1574, 26, 797, "Text"],
Cell[14525, 378, 12408, 306, 1065, "Input"],
Cell[26936, 686, 103, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[27064, 691, 153, 3, 36, "Input"],
Cell[27220, 696, 482, 7, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27751, 709, 94, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[27870, 714, 24526, 550, 1511, "Input"],
Cell[52399, 1266, 21498, 444, 1011, "Output"]
}, Open  ]],
Cell[73912, 1713, 1007, 17, 204, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
